#pragma once

class App;

namespace pp::panopainter {

[[nodiscard]] bool execute_legacy_app_request_close(App& app);
void execute_legacy_app_renderdoc_frame_start(App& app);
void execute_legacy_app_renderdoc_frame_end(App& app);
void execute_legacy_app_render_thread_main(App& app);
void execute_legacy_app_render_thread_start(App& app);
void execute_legacy_app_render_thread_stop(App& app);
void execute_legacy_app_ui_thread_tick(App& app);
void execute_legacy_app_ui_thread_main(App& app);
void execute_legacy_app_ui_thread_start(App& app);
void execute_legacy_app_ui_thread_stop(App& app);

} // namespace pp::panopainter
